<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label=" 宣教分类 " prop="preachcategoryid">
        <el-input v-model="queryParams.preachcategoryid" placeholder="请输入 宣教分类 " clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label=" 宣教分类 " prop="classification">
        <el-input v-model="queryParams.classification" placeholder="请输入 宣教分类 " clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label=" 宣教名称 " prop="preachname">
        <el-input v-model="queryParams.preachname" placeholder="请输入 宣教名称 " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label=" 宣教形式 " prop="preachform">
        <el-input v-model="queryParams.preachform" placeholder="请输入 宣教形式 " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label=" 是否启用 " prop="isenable">
        <el-input v-model="queryParams.isenable" placeholder="请输入 是否启用 " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label=" 机构ID " prop="orgid">
        <el-input v-model="queryParams.orgid" placeholder="请输入 机构ID " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['smartor:helibrary:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['smartor:helibrary:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['smartor:helibrary:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['smartor:helibrary:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="helibraryList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label=" 自增ID " align="center" prop="id" />
      <el-table-column label=" 宣教分类 " align="center" prop="preachcategoryid" />
      <el-table-column label=" 宣教名称 " align="center" prop="preachname" />
      <el-table-column label=" 宣教形式 " align="center" prop="preachform" />
      <el-table-column label=" 宣教描述 " align="center" prop="preachdescription" />
      <el-table-column label=" 宣教内容 " align="center" prop="preachcontent" />
      <el-table-column label=" 模板ID " align="center" prop="templateid" />
      <el-table-column label=" 宣教代码 " align="center" prop="preachcode" />
      <el-table-column label=" 是否启用 " align="center" prop="isenable" />
      <el-table-column label=" 机构ID " align="center" prop="orgid" />
      <el-table-column label=" 宣教分类 " align="center" prop="classification" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:helibrary:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:helibrary:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改宣教库对话框 -->
    <el-dialog :title="title" :visible.sync="open" :show-close="true" :close-on-click-modal="false" width="1000px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" :inline="true" label-width="120px">
        <el-form-item label=" 宣教分类 " prop="preachcategoryid">
          <el-input v-model="form.preachcategoryid" placeholder="请输入 宣教分类 " />
        </el-form-item>
        <el-form-item label=" 宣教名称 " prop="preachname">
          <el-input v-model="form.preachname" placeholder="请输入 宣教名称 " />
        </el-form-item>
        <el-form-item label=" 版本 " prop="version">
          <el-input v-model="form.version" placeholder="请输入 版本 " />
        </el-form-item>
        <el-form-item label=" 宣教形式 " prop="preachform">
          <el-input v-model="form.preachform" placeholder="请输入 宣教形式 " />
        </el-form-item>
        <el-form-item label=" 宣教描述 " prop="preachdescription">
          <el-input v-model="form.preachdescription" type="textarea" placeholder="请输入内容" />
        </el-form-item>
        <el-form-item label=" 宣教内容 ">
          <el-input v-model="form.preachcontent" type="textarea" placeholder="请输入" />
        </el-form-item>
        <el-form-item label=" 模板ID " prop="templateid">
          <el-input v-model="form.templateid" placeholder="请输入 模板ID " />
        </el-form-item>
        <el-form-item label=" 宣教代码 " prop="preachcode">
          <el-input v-model="form.preachcode" placeholder="请输入 宣教代码 " />
        </el-form-item>
        <el-form-item label=" 中心库ID " prop="centerlibraryid">
          <el-input v-model="form.centerlibraryid" placeholder="请输入 中心库ID " />
        </el-form-item>
        <el-form-item label=" 是否启用 " prop="isenable">
          <el-input v-model="form.isenable" placeholder="请输入 是否启用 " />
        </el-form-item>
        <el-form-item label=" 机构ID " prop="orgid">
          <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
        </el-form-item>
        <el-form-item label=" 删除标记 " prop="delFlag">
          <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
        </el-form-item>
        <el-form-item label=" 上传标记 " prop="isupload">
          <el-input v-model="form.isupload" placeholder="请输入 上传标记 " />
        </el-form-item>
        <el-form-item label=" 上传时间 " prop="uploadTime">
          <el-date-picker clearable v-model="form.uploadTime" type="date" value-format="yyyy-MM-dd"
            placeholder="请选择 上传时间 ">
          </el-date-picker>
        </el-form-item>
        <el-form-item label=" 宣教分类 " prop="classification">
          <el-input v-model="form.classification" placeholder="请输入 宣教分类 " />
        </el-form-item>
        <el-form-item label=" 是否本地 " prop="islocal">
          <el-input v-model="form.islocal" placeholder="请输入 是否本地 " />
        </el-form-item>
        <el-form-item label=" 中心库代码 " prop="centerlibrarycode">
          <el-input v-model="form.centerlibrarycode" placeholder="请输入 中心库代码 " />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listHelibrary, getHelibrary, delHelibrary, addHelibrary, updateHelibrary } from "@/api/smartor/helibrary";

export default {
  name: "Helibrary",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 宣教库表格数据
      helibraryList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        preachcategoryid: null,
        preachname: null,
        version: null,
        preachform: null,
        preachdescription: null,
        preachcontent: null,
        templateid: null,
        preachcode: null,
        centerlibraryid: null,
        isenable: null,
        orgid: null,
        isupload: null,
        uploadTime: null,
        classification: null,
        islocal: null,
        centerlibrarycode: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询宣教库列表 */
    getList() {
      this.loading = true;
      listHelibrary(this.queryParams).then(response => {
        this.helibraryList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        preachcategoryid: null,
        preachname: null,
        version: null,
        preachform: null,
        preachdescription: null,
        preachcontent: null,
        templateid: null,
        preachcode: null,
        centerlibraryid: null,
        isenable: null,
        orgid: null,
        updateBy: null,
        updateTime: null,
        delFlag: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        classification: null,
        islocal: null,
        centerlibrarycode: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加宣教库";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getHelibrary(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改宣教库";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateHelibrary(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addHelibrary(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除宣教库编号为"' + ids + '"的数据项？').then(function () {
        return delHelibrary(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/helibrary/export', {
        ...this.queryParams
      }, `helibrary_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
